============
Contributors
============

Vaurien was originally imagined & created by Alexis Métaireau &
Tarek Ziadé for the Mozilla Services Projects.

Contributors in order of appearance:

- Jeff Terrace - https://github.com/jterrace

